@@ -43,12 +43,16 @@ def make_cdes(schema_data):
 def validate_dataset_present_on_cdes_with_proper_format(cdes):
     dataset_cde = [cde for cde in cdes if cde.code == "dataset"]
     if not dataset_cde:
-        raise InvalidDataModelError("There is no dataset cde in the data model's CDEs")
+        raise InvalidDataModelError("There is no 'dataset' CDE in the data model.")
     dataset_metadata = json.loads(dataset_cde[0].metadata)
     if not dataset_metadata["is_categorical"]:
-        raise InvalidDataModelError("Dataset cde should be categorical")
+        raise InvalidDataModelError(
+            "CDE 'dataset' must have the 'isCategorical' property equal to 'true'."
+        )
     if dataset_metadata["sql_type"] != "text":
-        raise InvalidDataModelError("Dataset cde should have sql type 'text'")
+        raise InvalidDataModelError(
+            "CDE 'dataset' must have the 'sql_type' property equal to 'text'."
+        )
 
 
 def reformat_metadata(metadata):
