@@ -10,7 +10,7 @@ class Schema:
 
     def __init__(self, name) -> None:
         self.name = name
-        self._is_schema_name_valid_python_identifier()
+        self._validate_schema_name()
         self.schema = sql.MetaData(schema=self.name)
 
     def __repr__(self) -> str:
@@ -22,6 +22,6 @@ class Schema:
     def drop(self, db: DataBase):
         db.drop_schema(self.name)
 
-    def _is_schema_name_valid_python_identifier(self):
+    def _validate_schema_name(self):
         if '"' in self.name:
-            raise UserInputError(f'Data model\'s name: {self.name} is not a valid python identifier')
+            raise UserInputError(f'Data model\'s name: {self.name} contains prohibited character double quotes (")')
